@@ -209,8 +209,9 @@ class TableHandler(TableHandlerInterface):
             if (base_type == 'varchar'
                     and self._columns[column_name]['typname'] == 'varchar'):
                 # Migrate size
+                from_size = self._columns[column_name]['size']
                 if field_size is None:
-                    if self._columns[column_name]['size'] != 255:
+                    if from_size != 255:
                         self.alter_size(column_name, base_type)
                 elif self._columns[column_name]['size'] == field_size:
                     pass
@@ -219,8 +220,7 @@ class TableHandler(TableHandlerInterface):
                         'Unable to migrate column %s on table %s '
                         'from varchar(%s) to varchar(%s).',
                         column_name, self.table_name,
-                        self._columns[column_name]['size'] > 0
-                        and self._columns[column_name]['size'] or 255,
+                        from_size if from_size and from_size > 0 else 255,
                         field_size)
             return
 
