@@ -7,15 +7,13 @@ class TableHandlerInterface(object):
     Define generic interface to handle database table
     '''
 
-    def __init__(self, cursor, model, module_name=None, history=False):
+    def __init__(self, model, module_name=None, history=False):
         '''
-        :param cursor: the database cursor
         :param model: the Model linked to the table
         :param module_name: the module name
         :param history: a boolean to define if it is a history table
         '''
         super(TableHandlerInterface, self).__init__()
-        self.cursor = cursor
         if history:
             self.table_name = model._table + '__history'
         else:
@@ -29,44 +27,40 @@ class TableHandlerInterface(object):
         self.history = history
 
     @staticmethod
-    def table_exist(cursor, table_name):
+    def table_exist(table_name):
         '''
         Table exist
 
-        :param cursor: the database cursor
         :param table_name: the table name
         :return: a boolean
         '''
         raise NotImplementedError
 
     @staticmethod
-    def table_rename(cursor, old_name, new_name):
+    def table_rename(old_name, new_name):
         '''
         Rename table
 
-        :param cursor: the database cursor
         :param old_name: the old table name
         :param new_name: the new table name
         '''
         raise NotImplementedError
 
     @staticmethod
-    def sequence_exist(cursor, sequence_name):
+    def sequence_exist(sequence_name):
         '''
         Sequence exist
 
-        :param cursor: the database cursor
         :param sequence_name: the sequence name
         :return: a boolean
         '''
         raise NotImplementedError
 
     @staticmethod
-    def sequence_rename(cursor, old_name, new_name):
+    def sequence_rename(old_name, new_name):
         '''
         Rename sequence
 
-        :param cursor: the database cursor
         :param old_name: the old sequence name
         :param new_name: the new sequence name
         '''
@@ -206,7 +200,7 @@ class TableHandlerInterface(object):
         raise NotImplementedError
 
     @staticmethod
-    def drop_table(cursor, model, table, cascade=False):
+    def drop_table(model, table, cascade=False):
         '''
         Remove a table and clean ir_model_data from the given model.
 
