@@ -2,27 +2,26 @@
 # this repository contains the full copyright notices and license terms.
 import re
 import heapq
+import json
 
 from sql import Null
 from sql.aggregate import Max
 from sql.conditionals import Case
 from collections import defaultdict
-try:
-    import simplejson as json
-except ImportError:
-    import json
+from itertools import groupby
 
-from ..model import ModelView, ModelSQL, Workflow, fields, Unique
+from ..model import (ModelView, ModelSQL, Workflow, fields, Unique,
+    EvalEnvironment)
 from ..report import Report
 from ..wizard import Wizard, StateView, StateAction, Button
 from ..transaction import Transaction
 from ..cache import Cache
 from ..pool import Pool
-from ..pyson import Bool, Eval
+from ..pyson import Bool, Eval, PYSONDecoder
 from ..rpc import RPC
 from .. import backend
 from ..protocols.jsonrpc import JSONDecoder, JSONEncoder
-from ..tools import is_instance_method, cursor_dict
+from ..tools import is_instance_method, cursor_dict, grouped_slice
 try:
     from ..tools.StringMatcher import StringMatcher
 except ImportError:
@@ -30,12 +29,11 @@ except ImportError:
 
 __all__ = [
     'Model', 'ModelField', 'ModelAccess', 'ModelFieldAccess', 'ModelButton',
+    'ModelButtonRule', 'ModelButtonClick', 'ModelButtonReset',
     'ModelData', 'PrintModelGraphStart', 'PrintModelGraph', 'ModelGraph',
     'ModelWorkflowGraph',
     ]
 
-IDENTIFIER = re.compile(r'^[a-zA-z_][a-zA-Z0-9_]*$')
-
 
 class Model(ModelSQL, ModelView):
     "Model"
@@ -70,10 +68,6 @@ class Model(ModelSQL, ModelView):
             ('model_uniq', Unique(table, table.model),
                 'The model must be unique!'),
             ]
-        cls._error_messages.update({
-                'invalid_module': ('Module name "%s" is not a valid python '
-                    'identifier.'),
-                })
         cls._order.insert(0, ('model', 'ASC'))
         cls.__rpc__.update({
                 'list_models': RPC(),
@@ -114,20 +108,6 @@ class Model(ModelSQL, ModelView):
                     where=ir_model.id == model_id))
         return model_id
 
-    @classmethod
-    def validate(cls, models):
-        super(Model, cls).validate(models)
-        cls.check_module(models)
-
-    @classmethod
-    def check_module(cls, models):
-        '''
-        Check module
-        '''
-        for model in models:
-            if model.module and not IDENTIFIER.match(model.module):
-                cls.raise_user_error('invalid_module', (model.rec_name,))
-
     @classmethod
     def list_models(cls):
         'Return a list of all models names'
@@ -256,10 +236,6 @@ class ModelField(ModelSQL, ModelView):
             ('name_model_uniq', Unique(table, table.name, table.model),
                 'The field name in model must be unique!'),
             ]
-        cls._error_messages.update({
-                'invalid_name': ('Model Field name "%s" is not a valid python '
-                    'identifier.'),
-                })
         cls._order.insert(0, ('name', 'ASC'))
 
     @classmethod
@@ -329,20 +305,6 @@ class ModelField(ModelSQL, ModelView):
     def default_field_description():
         return 'No description available'
 
-    @classmethod
-    def validate(cls, fields):
-        super(ModelField, cls).validate(fields)
-        cls.check_name(fields)
-
-    @classmethod
-    def check_name(cls, fields):
-        '''
-        Check name
-        '''
-        for field in fields:
-            if not IDENTIFIER.match(field.name):
-                cls.raise_user_error('invalid_name', (field.name,))
-
     @classmethod
     def read(cls, ids, fields_names=None):
         pool = Pool()
@@ -767,6 +729,25 @@ class ModelButton(ModelSQL, ModelView):
     groups = fields.Many2Many('ir.model.button-res.group', 'button', 'group',
         'Groups')
     _groups_cache = Cache('ir.model.button.groups')
+    rules = fields.One2Many('ir.model.button.rule', 'button', "Rules")
+    _rules_cache = Cache('ir.model.button.rules')
+    clicks = fields.One2Many('ir.model.button.click', 'button', "Clicks")
+    reset_by = fields.Many2Many(
+        'ir.model.button-button.reset', 'button_ruled', 'button', "Reset by",
+        domain=[
+            ('model', '=', Eval('model', -1)),
+            ('id', '!=', Eval('id', -1)),
+            ],
+        depends=['model', 'id'],
+        help="Button that should reset the rules")
+    reset = fields.Many2Many(
+        'ir.model.button-button.reset', 'button', 'button_ruled', "Reset",
+        domain=[
+            ('model', '=', Eval('model', -1)),
+            ('id', '!=', Eval('id', -1)),
+            ],
+        depends=['model', 'id'])
+    _reset_cache = Cache('ir.model.button.reset')
 
     @classmethod
     def __setup__(cls):
@@ -781,21 +762,27 @@ class ModelButton(ModelSQL, ModelView):
     @classmethod
     def create(cls, vlist):
         result = super(ModelButton, cls).create(vlist)
-        # Restart the cache for get_groups
+        # Restart the cache for get_groups and get_rules
         cls._groups_cache.clear()
+        cls._rules_cache.clear()
+        cls._reset_cache.clear()
         return result
 
     @classmethod
     def write(cls, buttons, values, *args):
         super(ModelButton, cls).write(buttons, values, *args)
-        # Restart the cache for get_groups
+        # Restart the cache for get_groups and get_rules
         cls._groups_cache.clear()
+        cls._rules_cache.clear()
+        cls._reset_cache.clear()
 
     @classmethod
     def delete(cls, buttons):
         super(ModelButton, cls).delete(buttons)
-        # Restart the cache for get_groups
+        # Restart the cache for get_groups and get_rules
         cls._groups_cache.clear()
+        cls._rules_cache.clear()
+        cls._reset_cache.clear()
 
     @classmethod
     def get_groups(cls, model, name):
@@ -818,6 +805,209 @@ class ModelButton(ModelSQL, ModelView):
         cls._groups_cache.set(key, groups)
         return groups
 
+    @classmethod
+    def get_rules(cls, model, name):
+        'Return a list of rules to apply on the named button of the model'
+        pool = Pool()
+        Rule = pool.get('ir.model.button.rule')
+        key = (model, name)
+        rule_ids = cls._rules_cache.get(key)
+        if rule_ids is not None:
+            return Rule.browse(rule_ids)
+        buttons = cls.search([
+                ('model.model', '=', model),
+                ('name', '=', name),
+                ])
+        if not buttons:
+            rules = []
+        else:
+            button, = buttons
+            rules = button.rules
+        cls._rules_cache.set(key, [r.id for r in rules])
+        return rules
+
+    @classmethod
+    def get_reset(cls, model, name):
+        "Return a list of button names to reset"
+        key = (model, name)
+        reset = cls._reset_cache.get(key)
+        if reset is not None:
+            return reset
+        buttons = cls.search([
+                ('model.model', '=', model),
+                ('name', '=', name),
+                ])
+        if not buttons:
+            reset = []
+        else:
+            button, = buttons
+            reset = [b.name for b in button.reset]
+        cls._reset_cache.set(key, reset)
+        return reset
+
+
+class ModelButtonRule(ModelSQL, ModelView):
+    "Model Button Rule"
+    __name__ = 'ir.model.button.rule'
+    button = fields.Many2One(
+        'ir.model.button', "Button", required=True, ondelete='CASCADE')
+    description = fields.Char('Description')
+    number_user = fields.Integer('Number of User', required=True)
+    condition = fields.Char(
+        "Condition",
+        help='A PYSON statement evaluated with the record represented by '
+        '"self"\nIt activate the rule if true.')
+
+    @classmethod
+    def __setup__(cls):
+        super(ModelButtonRule, cls).__setup__()
+        cls._error_messages.update({
+                'invalid_condition': ('Condition "%(condition)s" is not a '
+                    'valid PYSON expression on button rule "%(rule)s".'),
+                })
+
+    @classmethod
+    def default_number_user(cls):
+        return 1
+
+    @classmethod
+    def validate(cls, rules):
+        super(ModelButtonRule, cls).validate(rules)
+        cls.check_condition(rules)
+
+    @classmethod
+    def check_condition(cls, rules):
+        for rule in rules:
+            if not rule.condition:
+                continue
+            try:
+                PYSONDecoder(noeval=True).decode(rule.condition)
+            except Exception:
+                cls.raise_user_error('invalid_condition', {
+                        'condition': rule.condition,
+                        'rule': rule.rec_name,
+                        })
+
+    def test(self, record, clicks):
+        "Test if the rule passes for the record"
+        if self.condition:
+            env = {}
+            env['self'] = EvalEnvironment(record, record.__class__)
+            if not PYSONDecoder(env).decode(self.condition):
+                return True
+        if self.group:
+            users = {c.user for c in clicks if self.group in c.user.groups}
+        else:
+            users = {c.user for c in clicks}
+        return len(users) >= self.number_user
+
+    @classmethod
+    def create(cls, vlist):
+        pool = Pool()
+        ModelButton = pool.get('ir.model.button')
+        result = super(ModelButtonRule, cls).create(vlist)
+        # Restart the cache for get_rules
+        ModelButton._rules_cache.clear()
+        return result
+
+    @classmethod
+    def write(cls, buttons, values, *args):
+        pool = Pool()
+        ModelButton = pool.get('ir.model.button')
+        super(ModelButtonRule, cls).write(buttons, values, *args)
+        # Restart the cache for get_rules
+        ModelButton._rules_cache.clear()
+
+    @classmethod
+    def delete(cls, buttons):
+        pool = Pool()
+        ModelButton = pool.get('ir.model.button')
+        super(ModelButtonRule, cls).delete(buttons)
+        # Restart the cache for get_rules
+        ModelButton._rules_cache.clear()
+
+
+class ModelButtonClick(ModelSQL, ModelView):
+    "Model Button Click"
+    __name__ = 'ir.model.button.click'
+    button = fields.Many2One(
+        'ir.model.button', "Button", required=True, ondelete='CASCADE')
+    record_id = fields.Integer("Record ID", required=True)
+    active = fields.Boolean("Active")
+
+    @classmethod
+    def __setup__(cls):
+        super(ModelButtonClick, cls).__setup__()
+        cls.__rpc__.update({
+                'get_click': RPC(),
+                })
+
+    @classmethod
+    def default_active(cls):
+        return True
+
+    @classmethod
+    def register(cls, model, name, records):
+        pool = Pool()
+        Button = pool.get('ir.model.button')
+
+        assert all(r.__class__.__name__ == model for r in records)
+
+        user = Transaction().user
+        button, = Button.search([
+                ('model.model', '=', model),
+                ('name', '=', name),
+                ])
+        cls.create([{
+                    'button': button.id,
+                    'record_id': r.id,
+                    'user': user,
+                    } for r in records])
+
+        clicks = defaultdict(list)
+        for records in grouped_slice(records):
+            clicks.update(groupby(cls.search([
+                            ('button', '=', button.id),
+                            ('record_id', 'in', [r.id for r in records]),
+                            ], order=[('record_id', 'ASC')]),
+                    key=lambda c: c.record_id))
+        return clicks
+
+    @classmethod
+    def reset(cls, model, names, records):
+        assert all(r.__class__.__name__ == model for r in records)
+
+        clicks = []
+        for records in grouped_slice(records):
+            clicks.extend(cls.search([
+                        ('button.model.model', '=', model),
+                        ('button.name', 'in', names),
+                        ('record_id', 'in', [r.id for r in records]),
+                        ]))
+        cls.write(clicks, {
+                'active': False,
+                })
+
+    @classmethod
+    def get_click(cls, model, button, record_id):
+        clicks = cls.search([
+                ('button.model.model', '=', model),
+                ('button.name', '=', button),
+                ('record_id', '=', record_id),
+                ])
+        return {c.user.id: c.user.rec_name for c in clicks}
+
+
+class ModelButtonReset(ModelSQL):
+    "Model Button Reset"
+    __name__ = 'ir.model.button-button.reset'
+    button_ruled = fields.Many2One(
+        'ir.model.button', "Button Ruled",
+        required=True, ondelete='CASCADE', select=True)
+    button = fields.Many2One(
+        'ir.model.button', "Button",
+        required=True, ondelete='CASCADE', select=True)
+
 
 class ModelData(ModelSQL, ModelView):
     "Model data"
@@ -934,6 +1124,7 @@ class ModelData(ModelSQL, ModelView):
     def sync(cls, records):
         pool = Pool()
         to_write = []
+        models_to_write = defaultdict(list)
         for data in records:
             Model = pool.get(data.model)
             values = cls.load_values(data.values)
@@ -942,11 +1133,12 @@ class ModelData(ModelSQL, ModelView):
             # if they come from version < 3.2
             if values != fs_values:
                 record = Model(data.db_id)
-                Model.write([record], fs_values)
-                values = fs_values
+                models_to_write[Model].extend(([record], fs_values))
             to_write.extend([[data], {
-                        'values': cls.dump_values(values),
+                        'values': cls.dump_values(fs_values),
                         }])
+        for Model, values_to_write in models_to_write.iteritems():
+            Model.write(*values_to_write)
         if to_write:
             cls.write(*to_write)
 
