@@ -10,8 +10,9 @@ from .dictschema import DictSchemaMixin
 from .match import MatchMixin
 from .union import UnionMixin
 from .descriptors import dualmethod
+from .order import sequence_ordered
 
 __all__ = ['Model', 'ModelView', 'ModelStorage', 'ModelSingleton', 'ModelSQL',
     'Check', 'Unique',
     'Workflow', 'DictSchemaMixin', 'MatchMixin', 'UnionMixin', 'dualmethod',
-    'EvalEnvironment']
+    'EvalEnvironment', 'sequence_ordered']
