@@ -1,5 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+import sys
 import warnings
 
 from sql import Query, Expression
@@ -53,7 +54,7 @@ class Char(FieldTranslate):
             return value
         if value is None:
             return None
-        elif isinstance(value, str):
+        elif isinstance(value, str) and sys.version_info < (3,):
             return unicode(value, 'utf-8')
         assert isinstance(value, unicode)
         return value
