@@ -6,7 +6,7 @@ from sql import Cast, Literal, Null
 from sql.functions import Substring, Position
 from sql.conditionals import Coalesce
 
-from .field import Field, size_validate
+from .field import Field, size_validate, instanciate_values
 from ...pool import Pool
 from ...tools import grouped_slice
 from ...transaction import Transaction
@@ -232,16 +232,7 @@ class Many2Many(Field):
 
     def __set__(self, inst, value):
         Target = self.get_target()
-
-        def instance(data):
-            if isinstance(data, Target):
-                return data
-            elif isinstance(data, dict):
-                return Target(**data)
-            else:
-                return Target(data)
-        value = tuple(instance(x) for x in (value or []))
-        super(Many2Many, self).__set__(inst, value)
+        super(Many2Many, self).__set__(inst, instanciate_values(Target, value))
 
     def convert_domain_tree(self, domain, tables):
         Target = self.get_target()
