@@ -1,13 +1,20 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from decimal import Decimal
-from sql import Query, Expression, Cast, Literal, Select, CombiningQuery
+from sql import Query, Expression, Cast, Literal, Select, CombiningQuery, As
 
 from ... import backend
 from .field import SQLType
 from .float import Float
 
 
+class SQLite_Cast(Cast):
+
+    def as_(self, output_name):
+        # Use PARSE_COLNAMES instead of CAST for final column
+        return As(self.expression, '%s [NUMERIC]' % output_name)
+
+
 class Numeric(Float):
     '''
     Define a numeric field (``decimal``).
@@ -36,7 +43,7 @@ class Numeric(Float):
         db_type = backend.name()
         if db_type == 'sqlite':
             # Must be casted as Decimal is stored as bytes
-            column = Cast(column, self.sql_type().base)
+            column = SQLite_Cast(column, self.sql_type().base)
         return column
 
     def _domain_value(self, operator, value):
