@@ -8,7 +8,7 @@ import warnings
 
 from decimal import Decimal
 from itertools import islice, ifilter, chain, izip
-from functools import reduce
+from functools import reduce, wraps
 from operator import itemgetter
 from collections import defaultdict
 
@@ -30,6 +30,14 @@ from .descriptors import dualmethod
 __all__ = ['ModelStorage', 'EvalEnvironment']
 
 
+def without_check_access(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        with Transaction().set_context(_check_access=False):
+            return func(*args, **kwargs)
+    return wrapper
+
+
 def cache_size():
     return Transaction().context.get('_record_cache_size',
         config.getint('cache', 'record'))
@@ -96,6 +104,7 @@ class ModelStorage(Model):
         Transaction().counter += 1
 
     @classmethod
+    @without_check_access
     def trigger_create(cls, records):
         '''
         Trigger create actions
@@ -191,6 +200,7 @@ class ModelStorage(Model):
         return eligibles
 
     @classmethod
+    @without_check_access
     def trigger_write(cls, eligibles):
         '''
         Trigger write actions.
@@ -229,6 +239,7 @@ class ModelStorage(Model):
                             del cache[cls.__name__][record.id]
 
     @classmethod
+    @without_check_access
     def trigger_delete(cls, records):
         '''
         Trigger delete actions
@@ -355,7 +366,7 @@ class ModelStorage(Model):
         '''
         Return the number of records that match the domain.
         '''
-        res = cls.search(domain, count=True)
+        res = cls.search(domain, order=[], count=True)
         if isinstance(res, list):
             return len(res)
         return res
@@ -1338,6 +1349,7 @@ class ModelStorage(Model):
         # Read the data
         with Transaction().set_current_transaction(self._transaction), \
                 self._transaction.set_user(self._user), \
+                self._transaction.reset_context(), \
                 self._transaction.set_context(self._context):
             if self.id in self._cache and name in self._cache[self.id]:
                 # Use values from cache
@@ -1460,6 +1472,7 @@ class ModelStorage(Model):
             try:
                 with transaction.set_current_transaction(transaction), \
                         transaction.set_user(user), \
+                        transaction.reset_context(), \
                         transaction.set_context(context):
                     if to_create:
                         news = cls.create([save_values[r] for r in to_create])
