@@ -2,15 +2,12 @@
 # this repository contains the full copyright notices and license terms.
 import datetime
 from decimal import Decimal
-try:
-    import simplejson as json
-except ImportError:
-    import json
+import json
 import base64
 
 from werkzeug.wrappers import Response
 from werkzeug.utils import cached_property
-from werkzeug.exceptions import BadRequest
+from werkzeug.exceptions import BadRequest, InternalServerError
 
 from trytond.protocols.wrappers import Request
 from trytond.exceptions import TrytonException
@@ -53,11 +50,6 @@ class JSONEncoder(json.JSONEncoder):
 
     serializers = {}
 
-    def __init__(self, *args, **kwargs):
-        super(JSONEncoder, self).__init__(*args, **kwargs)
-        # Force to use our custom decimal with simplejson
-        self.use_decimal = False
-
     @classmethod
     def register(cls, klass, encoder):
         assert klass not in cls.serializers
@@ -129,11 +121,11 @@ class JSONRequest(Request):
             raise BadRequest('Not a JSON request')
 
     @cached_property
-    def method(self):
+    def rpc_method(self):
         return self.parsed_data['method']
 
     @cached_property
-    def params(self):
+    def rpc_params(self):
         return self.parsed_data['params']
 
 
@@ -146,16 +138,23 @@ class JSONProtocol:
 
     @classmethod
     def response(cls, data, request):
-        if isinstance(request, JSONRequest):
-            response = {'id': request.parsed_data.get('id', 0)}
+        try:
+            parsed_data = request.parsed_data
+        except BadRequest:
+            parsed_data = {}
+        if (isinstance(request, JSONRequest)
+                and set(parsed_data.keys()) == {'id', 'method', 'params'}):
+            response = {'id': parsed_data.get('id', 0)}
+            if isinstance(data, TrytonException):
+                response['error'] = data.args
+            elif isinstance(data, Exception):
+                # report exception back to server
+                response['error'] = (str(data), data.__format_traceback__)
+            else:
+                response['result'] = data
         else:
-            response = {}
-        if isinstance(data, TrytonException):
-            response['error'] = data.args
-        elif isinstance(data, Exception):
-            # report exception back to server
-            response['error'] = (str(data), data.__format_traceback__)
-        else:
-            response['result'] = data
+            if isinstance(data, Exception):
+                return InternalServerError()
+            response = data
         return Response(json.dumps(response, cls=JSONEncoder),
             content_type='application/json')
