@@ -1,14 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-try:
-    import crypt
-except ImportError:
-    pass
-
 from trytond.pool import Pool
 from trytond.config import config
 from trytond.transaction import Transaction
 from trytond import backend
+from trytond.exceptions import LoginException
 
 
 def _get_pool(dbname):
@@ -19,11 +15,24 @@ def _get_pool(dbname):
     return pool
 
 
-def login(dbname, loginname, password, cache=True):
-    with Transaction().start(dbname, 0):
-        pool = _get_pool(dbname)
-        User = pool.get('res.user')
-        user_id = User.get_login(loginname, password)
+def login(dbname, loginname, parameters, cache=True, language=None):
+    DatabaseOperationalError = backend.get('DatabaseOperationalError')
+    context = {'language': language}
+    for count in range(config.getint('database', 'retry'), -1, -1):
+        with Transaction().start(dbname, 0, context=context) as transaction:
+            pool = _get_pool(dbname)
+            User = pool.get('res.user')
+            try:
+                user_id = User.get_login(loginname, parameters)
+            except DatabaseOperationalError:
+                if count:
+                    continue
+                raise
+            except LoginException:
+                # Let's store any changes done
+                transaction.commit()
+                raise
+        break
     if user_id:
         if not cache:
             return user_id
@@ -35,25 +44,25 @@ def login(dbname, loginname, password, cache=True):
 
 
 def logout(dbname, user, session):
-    with Transaction().start(dbname, 0):
-        pool = _get_pool(dbname)
-        Session = pool.get('ir.session')
-        sessions = Session.search([
-                ('key', '=', session),
-                ])
-        if not sessions:
-            return
-        session, = sessions
-        name = session.create_uid.login
-        Session.delete(sessions)
-    return name
-
-
-def check_super(passwd):
-    cryptedpasswd = config.get('session', 'super_pwd')
-    if cryptedpasswd and crypt.crypt(passwd, cryptedpasswd) == cryptedpasswd:
-        return True
-    raise Exception('AccessDenied')
+    DatabaseOperationalError = backend.get('DatabaseOperationalError')
+    for count in range(config.getint('database', 'retry'), -1, -1):
+        with Transaction().start(dbname, 0):
+            pool = _get_pool(dbname)
+            Session = pool.get('ir.session')
+            try:
+                sessions = Session.search([
+                        ('key', '=', session),
+                        ])
+                if not sessions:
+                    return
+                session, = sessions
+                name = session.create_uid.login
+                Session.delete(sessions)
+            except DatabaseOperationalError:
+                if count:
+                    continue
+                raise
+        return name
 
 
 def check(dbname, user, session):
