@@ -101,9 +101,13 @@ def register():
         Binary,
         BinaryDefault,
         BinaryRequired,
+        BinaryFileStorage,
+        Model,
         Singleton,
         URLObject,
         ModelStorage,
+        ModelStorageRequired,
+        ModelStorageContext,
         ModelSQLRequiredField,
         ModelSQLTimestamp,
         ModelSQLFieldSet,
@@ -116,8 +120,10 @@ def register():
         Model4UnionTree1,
         Model4UnionTree2,
         UnionTree,
+        SequenceOrderedModel,
         ModelViewChangedValues,
         ModelViewChangedValuesTarget,
+        ModelViewButton,
         MPTT,
         ImportDataBoolean,
         ImportDataInteger,
