@@ -3,7 +3,7 @@
 # this repository contains the full copyright notices and license terms.
 import unittest
 import datetime
-from trytond.tests.test_tryton import install_module, with_transaction
+from trytond.tests.test_tryton import activate_module, with_transaction
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.exceptions import UserError
@@ -14,7 +14,7 @@ class SequenceTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        install_module('tests')
+        activate_module('tests')
 
     @with_transaction()
     def test_incremental(self):
