@@ -6,42 +6,44 @@ import sys
 import unittest
 import doctest
 import re
+import subprocess
 from itertools import chain
 import operator
 from functools import wraps
 
 from lxml import etree
+from sql import Table
 
 from trytond.pool import Pool, isregisteredby
 from trytond import backend
 from trytond.model import Workflow
 from trytond.model.fields import get_eval_fields
-from trytond.protocols.dispatcher import create, drop
 from trytond.tools import is_instance_method
 from trytond.transaction import Transaction
-from trytond import security
 from trytond.cache import Cache
+from trytond.config import config, parse_uri
 
-__all__ = ['POOL', 'DB_NAME', 'USER', 'USER_PASSWORD', 'CONTEXT',
-    'install_module', 'ModuleTestCase', 'with_transaction',
+__all__ = ['POOL', 'DB_NAME', 'USER', 'CONTEXT',
+    'activate_module', 'ModuleTestCase', 'with_transaction',
     'doctest_setup', 'doctest_teardown', 'doctest_checker',
     'suite', 'all_suite', 'modules_suite']
 
 Pool.start()
 USER = 1
-USER_PASSWORD = 'admin'
 CONTEXT = {}
 DB_NAME = os.environ['DB_NAME']
+DB_CACHE = os.environ.get('DB_CACHE')
 DB = backend.get('Database')(DB_NAME)
 Pool.test = True
 POOL = Pool(DB_NAME)
-security.check_super = lambda *a, **k: True
 
 
-def install_module(name):
+def activate_module(name):
     '''
-    Install module for the tested database
+    Activate module for the tested database
     '''
+    if not db_exist(DB_NAME) and restore_db_cache(name):
+        return
     create_db()
     with Transaction().start(DB_NAME, 1) as transaction:
         Module = POOL.get('ir.module')
@@ -53,22 +55,106 @@ def install_module(name):
 
         modules = Module.search([
                 ('name', '=', name),
-                ('state', '!=', 'installed'),
+                ('state', '!=', 'activated'),
                 ])
 
-        if not modules:
-            return
+        if modules:
+            Module.activate(modules)
+            transaction.commit()
 
-        Module.install(modules)
-        transaction.commit()
+            ActivateUpgrade = POOL.get('ir.module.activate_upgrade',
+                type='wizard')
+            instance_id, _, _ = ActivateUpgrade.create()
+            transaction.commit()
+            ActivateUpgrade(instance_id).transition_upgrade()
+            ActivateUpgrade.delete(instance_id)
+            transaction.commit()
+    backup_db_cache(name)
 
-        InstallUpgrade = POOL.get('ir.module.install_upgrade',
-            type='wizard')
-        instance_id, _, _ = InstallUpgrade.create()
-        transaction.commit()
-        InstallUpgrade(instance_id).transition_upgrade()
-        InstallUpgrade.delete(instance_id)
-        transaction.commit()
+
+def restore_db_cache(name):
+    result = False
+    if DB_CACHE:
+        backend_name = backend.name()
+        cache_file = _db_cache_file(DB_CACHE, name, backend_name)
+        if os.path.exists(cache_file):
+            if backend_name == 'sqlite':
+                result = _sqlite_copy(cache_file, restore=True)
+            elif backend_name == 'postgresql':
+                result = _pg_restore(cache_file)
+    if result:
+        POOL.init()
+    return result
+
+
+def backup_db_cache(name):
+    if DB_CACHE:
+        if not os.path.exists(DB_CACHE):
+            os.makedirs(DB_CACHE)
+        backend_name = backend.name()
+        cache_file = _db_cache_file(DB_CACHE, name, backend_name)
+        if backend_name == 'sqlite':
+            _sqlite_copy(cache_file)
+        elif backend_name == 'postgresql':
+            _pg_dump(cache_file)
+
+
+def _db_cache_file(path, name, backend_name):
+    return os.path.join(path, '%s-%s-py%s.dump'
+        % (name, backend_name, sys.version_info.major))
+
+
+def _sqlite_copy(file_, restore=False):
+    try:
+        import sqlitebck
+    except ImportError:
+        return False
+    import sqlite3 as sqlite
+
+    with Transaction().start(DB_NAME, 0) as transaction, \
+            sqlite.connect(file_) as conn2:
+        conn1 = transaction.connection
+        # sqlitebck does not work with pysqlite2
+        if not isinstance(conn1, sqlite.Connection):
+            return False
+        if restore:
+            conn2, conn1 = conn1, conn2
+        sqlitebck.copy(conn1, conn2)
+    return True
+
+
+def _pg_options():
+    uri = parse_uri(config.get('database', 'uri'))
+    options = []
+    env = os.environ.copy()
+    if uri.hostname:
+        options.extend(['-h', uri.hostname])
+    if uri.port:
+        options.extend(['-p', str(uri.port)])
+    if uri.username:
+        options.extend(['-U', uri.username])
+    if uri.password:
+        env['PGPASSWORD'] = uri.password
+    return options, env
+
+
+def _pg_restore(cache_file):
+    with Transaction().start(None, 0, close=True, autocommit=True) \
+            as transaction:
+        transaction.database.create(transaction.connection, DB_NAME)
+    cmd = ['pg_restore', '-d', DB_NAME]
+    options, env = _pg_options()
+    cmd.extend(options)
+    cmd.append(cache_file)
+    return not subprocess.call(cmd, env=env)
+
+
+def _pg_dump(cache_file):
+    cmd = ['pg_dump', '-f', cache_file, '-F', 'c']
+    options, env = _pg_options()
+    cmd.extend(options)
+    cmd.append(DB_NAME)
+    return not subprocess.call(cmd, env=env)
 
 
 def with_transaction(user=1, context=None):
@@ -92,8 +178,8 @@ class ModuleTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        drop_create()
-        install_module(cls.module)
+        drop_db()
+        activate_module(cls.module)
         super(ModuleTestCase, cls).setUpClass()
 
     @classmethod
@@ -146,6 +232,20 @@ class ModuleTestCase(unittest.TestCase):
                         if field:
                             assert field in res['fields'], (
                                 'Missing field: %s' % field)
+                if element.tag == 'button':
+                    button_name = element.get('name')
+                    assert button_name in Model._buttons, (
+                        "Button '%s' is not in %s._buttons"
+                        % (button_name, Model.__name__))
+
+    @with_transaction()
+    def test_rpc_callable(self):
+        'Test that RPC methods are callable'
+        for _, model in Pool().iterobject():
+            for method_name in model.__rpc__:
+                assert callable(getattr(model, method_name, None)), (
+                    "'%s' is not callable on '%s'"
+                    % (method_name, model.__name__))
 
     @with_transaction()
     def test_depends(self):
@@ -205,6 +305,12 @@ class ModuleTestCase(unittest.TestCase):
                     elif attr.startswith('order_'):
                         tables = {None: (model.__table__(), None)}
                         getattr(model, attr)(tables)
+                    elif any(attr.startswith(p) for p in [
+                                'on_change_',
+                                'on_change_with_',
+                                'autocomplete_']):
+                        record = model()
+                        getattr(record, attr)()
 
     @with_transaction()
     def test_menu_action(self):
@@ -278,26 +384,59 @@ class ModuleTestCase(unittest.TestCase):
                     })
 
 
-def db_exist():
+def db_exist(name=DB_NAME):
     Database = backend.get('Database')
     database = Database().connect()
-    return DB_NAME in database.list()
+    return name in database.list()
 
 
-def create_db():
-    if not db_exist():
-        create(None, DB_NAME, None, 'en_US', USER_PASSWORD)
+def create_db(name=DB_NAME, lang='en'):
+    Database = backend.get('Database')
+    if not db_exist(name):
+        with Transaction().start(None, 0, close=True, autocommit=True) \
+                as transaction:
+            transaction.database.create(transaction.connection, name)
+
+        with Transaction().start(name, 0) as transaction,\
+                transaction.connection.cursor() as cursor:
+            Database(name).init()
+            ir_configuration = Table('ir_configuration')
+            cursor.execute(*ir_configuration.insert(
+                    [ir_configuration.language], [[lang]]))
+
+        pool = Pool(name)
+        pool.init(update=['res', 'ir'], lang=[lang])
+        with Transaction().start(name, 0) as transaction:
+            User = pool.get('res.user')
+            Lang = pool.get('ir.lang')
+            language, = Lang.search([('code', '=', lang)])
+            language.translatable = True
+            language.save()
+            users = User.search([('login', '!=', 'root')])
+            User.write(users, {
+                    'language': language.id,
+                    })
+            Module = pool.get('ir.module')
+            Module.update_list()
 
 
-def drop_db():
-    if db_exist():
-        drop(None, DB_NAME, None)
+def drop_db(name=DB_NAME):
+    if db_exist(name):
+        Database = backend.get('Database')
+        database = Database(name)
+        database.close()
+
+        with Transaction().start(None, 0, close=True, autocommit=True) \
+                as transaction:
+            database.drop(transaction.connection, name)
+            Pool.stop(name)
+            Cache.drop(name)
 
 
-def drop_create():
-    if db_exist():
-        drop_db()
-    create_db()
+def drop_create(name=DB_NAME, lang='en'):
+    if db_exist(name):
+        drop_db(name)
+    create_db(name, lang)
 
 doctest_setup = lambda test: drop_create()
 doctest_teardown = lambda test: drop_db()
