@@ -10,10 +10,10 @@ from trytond.transaction import Transaction
 
 __all__ = ['URLMixin']
 
-HOSTNAME = (config.get('jsonrpc', 'hostname')
-    or unicode(socket.getfqdn(), 'utf8'))
-HOSTNAME = '.'.join(encodings.idna.ToASCII(part) if part else ''
-    for part in HOSTNAME.split('.'))
+HOSTNAME = (config.get('web', 'hostname')
+    or socket.getfqdn())
+HOSTNAME = '.'.join(encodings.idna.ToASCII(part).decode('ascii')
+    if part else '' for part in HOSTNAME.split('.'))
 
 
 class URLAccessor(object):
@@ -34,7 +34,7 @@ class URLAccessor(object):
             raise NotImplementedError
 
         url_part['name'] = cls.__name__
-        url_part['database'] = Transaction().cursor.database_name
+        url_part['database'] = Transaction().database.name
 
         local_part = urllib.quote('%(database)s/%(type)s/%(name)s' % url_part)
         if isinstance(inst, Model) and inst.id:
